@@ -32,9 +32,12 @@ from doit import loader
 from doit.loader import create_after
 from doit.doit_cmd import get_var
 from doit.api import run
+from doit.tools import load_ipython_extension
 
 __all__ = ['get_var', 'run', 'create_after']
 
 def get_initial_workdir():
     """working-directory from where the doit command was invoked on shell"""
     return loader.initial_workdir
+
+assert load_ipython_extension  # silence pyflakes
\ No newline at end of file
