@@ -100,8 +100,8 @@ class TabCompletion(DoitCmdBase):
         if opt_values['hardcode_tasks']:
             self.task_list, _ = self.loader.load_tasks(
                 self, opt_values, pos_args)
-            tmpl_vars['pt_tasks'] = '"{0}"'.format(
-                ' '.join(t.name for t in self.task_list if not t.is_subtask))
+            task_names = (t.name for t in self.task_list if not t.subtask_of)
+            tmpl_vars['pt_tasks'] = '"{0}"'.format(' '.join(sorted(task_names)))
         else:
             tmpl_list_cmd = "$({0} list {1} --quiet 2>/dev/null)"
             tmpl_vars['pt_tasks'] = tmpl_list_cmd.format(pt_bin_name,
@@ -129,15 +129,15 @@ class TabCompletion(DoitCmdBase):
         # '(-c|--continue)'{-c,--continue}'[continue executing tasks...]' \
         # '--db-file[file used to save successful runs]' \
         if opt.short and opt.long:
-            tmpl = ("'(-{0.short}|--{0.long})'{{-{0.short},--{0.long}}}'"
-                    "[{help}]' \\")
+            tmpl = ('"(-{0.short}|--{0.long})"{{-{0.short},--{0.long}}}"'
+                    '[{help}]" \\')
         elif not opt.short and opt.long:
-            tmpl = "'--{0.long}[{help}]' \\"
+            tmpl = '"--{0.long}[{help}]" \\'
         elif opt.short and not opt.long:
-            tmpl = "'-{0.short}[{help}]' \\"
+            tmpl = '"-{0.short}[{help}]" \\'
         else: # without short or long options cant be really used
             return ''
-        ohelp = opt.help.replace(']', r'\]')
+        ohelp = opt.help.replace(']', r'\]').replace('"', r'\"')
         return tmpl.format(opt, help=ohelp).replace('\n', ' ')
 
 
@@ -194,9 +194,10 @@ class TabCompletion(DoitCmdBase):
                 self, opt_values, pos_args)
             lines = []
             for task in self.task_list:
-                if not task.is_subtask:
+                if not task.subtask_of:
                     lines.append("'{0}: {1}'".format(task.name, task.doc))
-            template_vars['pt_tasks'] = '(\n{0}\n)'.format('\n'.join(lines))
+            template_vars['pt_tasks'] = '(\n{0}\n)'.format(
+                '\n'.join(sorted(lines)))
         else:
             tmp_tasks = Template(
                 '''("${(f)$($pt_bin_name list --template '{name}: {doc}')}")''')
