@@ -2,6 +2,7 @@
 
 Built on top of getopt. optparse can't handle sub-commands.
 """
+import os
 import getopt
 import copy
 from collections import OrderedDict
@@ -14,7 +15,7 @@ class DefaultUpdate(dict):
 
     This is used when you have a dict that has multiple source of values
     (i.e. hardcoded, config file, command line). And values are updated
-    beggining from the source with higher priority.
+    beginning from the source with higher priority.
 
     A default value is added with the method set_default or add_defaults.
     """
@@ -40,7 +41,7 @@ class DefaultUpdate(dict):
         for key, value in update_dict.items():
             if key in self._non_default_keys:
                 continue
-            self[key] = value
+            self.set_default(key, value)
 
     def __setitem__(self, key, value):
         """overwrite to keep track of _non_default_keys"""
@@ -91,6 +92,7 @@ class CmdOption(object):
         self.inverse = opt_dict.pop('inverse', '')
         self.choices = dict(opt_dict.pop('choices', []))
         self.help = opt_dict.pop('help', '')
+        self.env_var = opt_dict.pop('env_var', None)
 
         # TODO add some hint for tab-completion scripts
 
@@ -133,7 +135,7 @@ class CmdOption(object):
     def str2type(self, str_val):
         """convert string value to option type value"""
         try:
-            # no coversion if value is not a string
+            # no conversion if value is not a string
             if not isinstance(str_val, str):
                 val = str_val
             elif self.type is bool:
@@ -207,8 +209,11 @@ class CmdOption(object):
         # TODO It should always display option's default value
         opt_help = self.help % {'default': self.default}
         opt_choices = self.help_choices()
+        opt_config = 'config: {}'.format(self.name)
+        opt_env = ', environ: {}'.format(self.env_var) if self.env_var else ''
 
-        text.append(self._print_2_columns(opt_str, opt_help + opt_choices))
+        desc = '{} {} ({}{})'.format(opt_help, opt_choices, opt_config, opt_env)
+        text.append(self._print_2_columns(opt_str, desc))
         # print bool inverse option
         if self.inverse:
             opt_str = '--%s' % self.inverse
@@ -288,6 +293,7 @@ class CmdParse(object):
                 opt = self._options[key]
                 opt.set_default(opt.str2type(val))
 
+
     def parse(self, in_args):
         """parse arguments into options(params) and positional arguments
 
@@ -302,7 +308,14 @@ class CmdParse(object):
         for opt in self._options.values():
             params.set_default(opt.name, opt.default)
 
-        # parse options using getopt
+        # get values from shell ENV
+        for opt in self._options.values():
+            if opt.env_var:
+                val = os.getenv(opt.env_var)
+                if val is not None:
+                    params[opt.name] = opt.str2type(val)
+
+        # parse cmdline options using getopt
         try:
             opts, args = getopt.getopt(in_args, self.get_short(),
                                        self.get_long())
