@@ -21,7 +21,7 @@ TASK_STRING = "task_"
 
 def flat_generator(gen, gen_doc=''):
     """return only values from generators
-    if any generator yields another generator it is recursivelly called
+    if any generator yields another generator it is recursively called
     """
     for item in gen:
         if inspect.isgenerator(item):
@@ -171,8 +171,8 @@ def _get_task_creators(namespace, command_names):
     for name, ref in namespace.items():
 
         # function is a task creator because of its name
-        if ((inspect.isfunction(ref) or inspect.ismethod(ref)) and
-            name.startswith(TASK_STRING)):
+        if name.startswith(TASK_STRING) and (
+                inspect.isfunction(ref) or inspect.ismethod(ref)):
             # remove TASK_STRING prefix from name
             task_name = name[prefix_len:]
 
@@ -216,7 +216,7 @@ def load_doit_config(dodo_module):
 
 
 def _generate_task_from_return(func_name, task_dict, gen_doc):
-    """generate a single task from a dict return'ed by a task generator"""
+    """generate a single task from a dict returned by a task generator"""
     if 'name' in task_dict:
         raise InvalidTask("Task '%s'. Only subtasks use field name." %
                           func_name)
@@ -232,7 +232,7 @@ def _generate_task_from_return(func_name, task_dict, gen_doc):
 
 
 def _generate_task_from_yield(tasks, func_name, task_dict, gen_doc):
-    """generate a single task from a dict yield'ed by task generator
+    """generate a single task from a dict yielded by task generator
 
     @param tasks: dictionary with created tasks
     @return None: the created task is added to 'tasks' dict
@@ -262,7 +262,7 @@ def _generate_task_from_yield(tasks, func_name, task_dict, gen_doc):
             raise InvalidTask(msg_dup % (func_name, full_name))
         task_dict['name'] = full_name
         sub_task = dict_to_task(task_dict)
-        sub_task.is_subtask = True
+        sub_task.subtask_of = basename
 
         # get/create task group
         group_task = tasks.get(basename)
