@@ -75,7 +75,7 @@ db_ext = {'dbhash': [''],
           }
 
 @pytest.fixture
-def depfile(request):
+def dep_manager(request):
     if hasattr(request, 'param'):
         dep_class = request.param
     else:
@@ -111,10 +111,6 @@ def depfile_name(request):
 
     return depfile_name
 
-@pytest.fixture
-def dep_manager(request, depfile_name):
-    return Dependency(DbmDB, depfile_name)
-
 
 @pytest.fixture
 def restore_cwd(request):
@@ -136,9 +132,9 @@ def tasks_sample():
         # 2
         Task("g1", None, doc="g1 doc string", has_subtask=True),
         # 3
-        Task("g1.a", [""], doc="g1.a doc string", is_subtask=True),
+        Task("g1.a", [""], doc="g1.a doc string", subtask_of='g1'),
         # 4
-        Task("g1.b", [""], doc="g1.b doc string", is_subtask=True),
+        Task("g1.b", [""], doc="g1.b doc string", subtask_of='g1'),
         # 5
         Task("t3", [""], doc="t3 doc string", task_dep=["t1"])
         ]
