@@ -1,4 +1,4 @@
-#! /usr/bin/env python
+#! /usr/bin/env python3
 
 # tests on CmdTask will use this script as an external process.
 # just print out all arguments
@@ -6,5 +6,5 @@
 import sys
 
 if __name__ == "__main__":
-    print " ".join(sys.argv[1:])
+    print(" ".join(sys.argv[1:]))
     sys.exit(0)
