@@ -10,6 +10,7 @@ from doit.task import Task
 from doit.cmd_base import version_tuple, Command, DoitCmdBase
 from doit.cmd_base import ModuleTaskLoader, DodoTaskLoader
 from doit.cmd_base import check_tasks_exist, tasks_and_deps_iter, subtasks_iter
+from .conftest import CmdFactory
 
 
 def test_version_tuple():
@@ -238,7 +239,7 @@ class TestDoitCmdBase(object):
         assert mycmd.dep_manager.db_class is mycmd._backends['j2']
 
 
-    def testPluginLoader(self, depfile_name):
+    def testPluginLoader(self):
         entry_point = {'mod': 'tests.sample_plugin:MyLoader'}
         mycmd = self.MyCmd(config={'GLOBAL': {'loader': 'mod'},
                                    'LOADER': entry_point})
@@ -247,6 +248,35 @@ class TestDoitCmdBase(object):
         assert task_list[0].name == 'sample_task'
         assert dodo_config == {'verbosity': 2}
 
+
+    def test_force_verbosity(self, dep_manager):
+        members = {
+            'DOIT_CONFIG': {'verbosity': 0},
+            'task_xxx1': lambda : {'actions':[]},
+        }
+        loader = ModuleTaskLoader(members)
+
+        class SampleCmd(DoitCmdBase):
+            opt_verbosity = {
+                'name':'verbosity',
+                'short':'v',
+                'long':'verbosity',
+                'type':int,
+                'default': None,
+                'help': "verbosity foo"
+            }
+            cmd_options = (opt_verbosity, )
+
+            def _execute(self, verbosity, force_verbosity):
+                return verbosity, force_verbosity
+
+        cmd = CmdFactory(SampleCmd, task_loader=loader, dep_manager=dep_manager)
+        assert (2, True) == cmd.parse_execute(
+            ['--db-file', dep_manager.name, '-v2'])
+        assert (0, False) == cmd.parse_execute(['--db-file', dep_manager.name])
+
+
+
 class TestCheckTasksExist(object):
     def test_None(self):
         check_tasks_exist({}, None)
@@ -298,9 +328,10 @@ class TestSubtaskIter(object):
     def test_sub_iter(self):
         tasks = {
             't1': Task("t1", [""] ),
-            't2': Task("t2", [""], task_dep=['t1', 't2:a', 't2:b']),
-            't2:a': Task("t2:a", [""], is_subtask=True),
-            't2:b': Task("t2:b", [""], is_subtask=True),
+            't1:x': Task("t1:x", [""], subtask_of='t1'),
+            't2': Task("t2", [""], task_dep=['t1', 't1:x', 't2:a', 't2:b']),
+            't2:a': Task("t2:a", [""], subtask_of='t2'),
+            't2:b': Task("t2:b", [""], subtask_of='t2'),
             }
         def names(task_name):
             return [t.name for t in subtasks_iter(tasks, tasks[task_name])]
