@@ -1,7 +1,7 @@
 import os
+from unittest.mock import Mock
 
 import pytest
-from mock import Mock
 
 from doit.exceptions import InvalidCommand
 from doit.cmd_run import Run
@@ -11,7 +11,9 @@ from doit import doit_cmd
 
 
 def cmd_main(args):
-    return doit_cmd.DoitMain().run(args)
+    main = doit_cmd.DoitMain()
+    main.BIN_NAME = 'doit'
+    return main.run(args)
 
 
 class TestRun(object):
@@ -43,6 +45,17 @@ class TestRun(object):
         cmd_main(['x=1', 'y=abc'])
         assert '1' == doit_cmd.get_var('x')
         assert 'abc' == doit_cmd.get_var('y')
+        assert None is doit_cmd.get_var('z')
+
+    def test_cmdline_novars(self, monkeypatch):
+        mock_run = Mock()
+        monkeypatch.setattr(Run, "execute", mock_run)
+        cmd_main(['x=1'])
+
+        # Simulate the variable below not being initialized by a subprocess on
+        # Windows. See https://github.com/pydoit/doit/issues/164.
+        doit_cmd._CMDLINE_VARS = None
+        assert None is doit_cmd.get_var('x')
 
     def test_cmdline_vars_not_opts(self, monkeypatch):
         mock_run = Mock()
