@@ -4,10 +4,16 @@ import threading
 
 import pytest
 
-from doit.filewatch import FileModifyWatcher
+from doit.filewatch import FileModifyWatcher, get_platform_system
 
 
+def testUnsuportedPlatform(monkeypatch):
+    monkeypatch.setattr(FileModifyWatcher, 'supported_platforms', ())
+    pytest.raises(Exception, FileModifyWatcher, [])
 
+
+platform = get_platform_system()
+@pytest.mark.skipif('platform not in FileModifyWatcher.supported_platforms')
 class TestFileWatcher(object):
     def testInit(self, restore_cwd, tmpdir):
         dir1 = 'data3'
@@ -31,10 +37,6 @@ class TestFileWatcher(object):
         assert tmpdir.join('data3') in fw.notify_dirs
 
 
-    def testUnsuportedPlatform(self, monkeypatch):
-        monkeypatch.setattr(FileModifyWatcher, 'supported_platforms', ())
-        pytest.raises(Exception, FileModifyWatcher, [])
-
     def testHandleEventNotSubclassed(self):
         fw = FileModifyWatcher([])
         pytest.raises(NotImplementedError, fw.handle_event, None)
