@@ -2,9 +2,9 @@ import os
 import pickle
 from multiprocessing import Queue
 import platform
+from unittest.mock import Mock
 
 import pytest
-from mock import Mock
 
 from doit.exceptions import InvalidTask
 from doit.dependency import DbmDB, Dependency
@@ -30,7 +30,9 @@ def simple_result():
 
 class FakeReporter(object):
     """Just log everything in internal attribute - used on tests"""
-    def __init__(self, outstream=None, options=None):
+    def __init__(self, with_exceptions=False, outstream=None, options=None):
+        # include Exception object of log failures
+        self.with_exceptions = with_exceptions
         self.log = []
 
     def get_status(self, task):
@@ -40,7 +42,10 @@ class FakeReporter(object):
         self.log.append(('execute', task))
 
     def add_failure(self, task, exception):
-        self.log.append(('fail', task))
+        if self.with_exceptions:
+            self.log.append(('fail', task, exception))
+        else:
+            self.log.append(('fail', task))
 
     def add_success(self, task):
         self.log.append(('success', task))
@@ -215,7 +220,7 @@ class TestRunner_SelectTask(object):
     def test_getargs_group(self, reporter, dep_manager):
         def ok(): return {'x':1}
         t1 = Task('t1', None, task_dep=['t1:a'], has_subtask=True)
-        t1a = Task('t1:a', [(ok,)], is_subtask=True)
+        t1a = Task('t1:a', [(ok,)], subtask_of='t1')
         t2 = Task('t2', None, getargs={'my_x':('t1', None)})
         tasks_dict = {'t1': t1, 't1a':t1a, 't2':t2}
         my_runner = runner.Runner(dep_manager, reporter)
@@ -231,7 +236,7 @@ class TestRunner_SelectTask(object):
     def test_getargs_group_value(self, reporter, dep_manager):
         def ok(): return {'x':1}
         t1 = Task('t1', None, task_dep=['t1:a'], has_subtask=True)
-        t1a = Task('t1:a', [(ok,)], is_subtask=True)
+        t1a = Task('t1:a', [(ok,)], subtask_of='t1')
         t2 = Task('t2', None, getargs={'my_x':('t1', 'x')})
         tasks_dict = {'t1': t1, 't1a':t1a, 't2':t2}
         my_runner = runner.Runner(dep_manager, reporter)
@@ -252,7 +257,7 @@ class TestTask_Teardown(object):
         t1 = Task('t1', [], teardown=[(touch,)])
         my_runner = runner.Runner(dep_manager, reporter)
         my_runner.teardown_list = [t1]
-        t1.execute()
+        t1.execute(my_runner.stream)
         my_runner.teardown()
         assert 1 == len(touched)
         assert ('teardown', t1) == reporter.log.pop(0)
@@ -264,8 +269,8 @@ class TestTask_Teardown(object):
         t2 = Task('t2', [], teardown=[do_nothing])
         my_runner = runner.Runner(dep_manager, reporter)
         my_runner.teardown_list = [t1, t2]
-        t1.execute()
-        t2.execute()
+        t1.execute(my_runner.stream)
+        t2.execute(my_runner.stream)
         my_runner.teardown()
         assert ('teardown', t2) == reporter.log.pop(0)
         assert ('teardown', t1) == reporter.log.pop(0)
@@ -278,8 +283,8 @@ class TestTask_Teardown(object):
         t2 = Task('t2', [], teardown=[(raise_something,['t2 blow'])])
         my_runner = runner.Runner(dep_manager, reporter)
         my_runner.teardown_list = [t1, t2]
-        t1.execute()
-        t2.execute()
+        t1.execute(my_runner.stream)
+        t2.execute(my_runner.stream)
         my_runner.teardown()
         assert ('teardown', t2) == reporter.log.pop(0)
         assert ('cleanup_error',) == reporter.log.pop(0)
@@ -394,6 +399,23 @@ class TestRunner_run_tasks(object):
         # second task is not executed
         assert 0 == len(reporter.log)
 
+    def test_dependency_error_after_execution(self, dep_manager):
+        t1 = Task("t1", [(my_print, ["out a"] )],
+                  file_dep=["i_dont_exist"], targets=['not_there'])
+        reporter = FakeReporter(with_exceptions=True)
+        my_runner = runner.Runner(dep_manager, reporter)
+        # Missing file_dep is not caught because check is short-circuited by
+        # missing target.
+        my_runner.run_tasks(TaskDispatcher({'t1':t1}, [], ['t1']))
+        assert runner.ERROR == my_runner.finish()
+        print(reporter.log)
+        assert ('start', t1) == reporter.log.pop(0)
+        assert ('execute', t1) == reporter.log.pop(0)
+        fail_log = reporter.log.pop(0)
+        assert ('fail', t1) == fail_log[:2]
+        assert "Dependent file 'i_dont_exist' does not exist" in str(fail_log[2])
+        assert not reporter.log
+
 
     # when successful dependencies are updated
     def test_updateDependencies(self, reporter, RunnerClass, depfile_name):
