@@ -2,6 +2,7 @@ import os, shutil
 import tempfile
 from io import StringIO
 from pathlib import Path, PurePath
+from sys import executable
 
 import pytest
 
@@ -9,14 +10,43 @@ from doit.exceptions import TaskError
 from doit.exceptions import CatchedException
 from doit import action
 from doit import task
+from doit.task import Stream
 
 #path to test folder
 TEST_PATH = os.path.dirname(__file__)
-PROGRAM = "python %s/sample_process.py" % TEST_PATH
+PROGRAM = "%s %s/sample_process.py" % (executable, TEST_PATH)
 
 
 
 
+class TestStream():
+
+    def test_from_task(self):
+        # use value from task, not global from Stream
+        v0 = Stream(0)
+        assert v0.effective_verbosity(1) == 1
+        assert v0.effective_verbosity(2) == 2
+        v2 = Stream(2)
+        assert v2.effective_verbosity(0) == 0
+        assert v2.effective_verbosity(1) == 1
+
+    def test_force_global(self):
+        # use value from task, not global from Stream
+        v0 = Stream(0, force_global=True)
+        assert v0.effective_verbosity(2) == 0
+        v2 = Stream(2, force_global=True)
+        assert v2.effective_verbosity(0) == 2
+
+    def test_task_verbosity_not_specified(self):
+        # default
+        v0 = Stream(None)
+        assert v0.effective_verbosity(None) == 1
+
+        v2 = Stream(2)
+        assert v2.effective_verbosity(None) == 2
+
+
+
 class TestTaskCheckInput(object):
 
     def testOkType(self):
@@ -78,7 +108,7 @@ class TestTaskInit(object):
         p1 = {'name':'p1', 'default':'p1-default'}
         p2 = {'name':'p2', 'default':'', 'short':'m'}
         t = task.Task("MyName", None, params=[p1, p2], pos_arg='pos')
-        t.execute()
+        t.execute(Stream(0))
         assert 'p1-default' == t.options['p1']
         assert '' == t.options['p2']
         assert 'pos' == t.pos_arg
@@ -257,14 +287,15 @@ class TestTaskRepr(object):
 class TestTaskActions(object):
     def test_success(self):
         t = task.Task("taskX", [PROGRAM])
-        t.execute()
+        t.execute(Stream(0))
 
 
     def test_result(self):
         # task.result is the value of last action
         t = task.Task('t1', ["%s hi_list hi1" % PROGRAM,
                              "%s hi_list hi2" % PROGRAM])
-        t.execute()
+        t.dep_changed = []
+        t.execute(Stream(0))
         assert "hi_listhi2" == t.result
 
     def test_values(self):
@@ -272,31 +303,32 @@ class TestTaskActions(object):
         # task.result is the value of last action
         t = task.Task('t1', [(return_dict, [{'x':5}]),
                              (return_dict, [{'y':10}]),])
-        t.execute()
+        t.execute(Stream(0))
         assert {'x':5, 'y':10} == t.values
 
     def test_failure(self):
         t = task.Task("taskX", ["%s 1 2 3" % PROGRAM])
-        got = t.execute()
+        got = t.execute(Stream(0))
         assert isinstance(got, TaskError)
 
     # make sure all cmds are being executed.
     def test_many(self):
         t = task.Task("taskX",["%s hi_stdout hi2" % PROGRAM,
                                "%s hi_list hi6" % PROGRAM])
-        t.execute()
+        t.dep_changed = []
+        t.execute(Stream(0))
         got = "".join([a.out for a in t.actions])
         assert "hi_stdouthi_list" == got, repr(got)
 
 
     def test_fail_first(self):
         t = task.Task("taskX", ["%s 1 2 3" % PROGRAM, PROGRAM])
-        got = t.execute()
+        got = t.execute(Stream(0))
         assert isinstance(got, TaskError)
 
     def test_fail_second(self):
         t = task.Task("taskX", ["%s 1 2" % PROGRAM, "%s 1 2 3" % PROGRAM])
-        got = t.execute()
+        got = t.execute(Stream(0))
         assert isinstance(got, TaskError)
 
 
@@ -307,7 +339,8 @@ class TestTaskActions(object):
         t = task.Task("taskX",["%s hi_stdout hi2" % PROGRAM,
                                (my_print,['_PY_']),
                                "%s hi_list hi6" % PROGRAM])
-        t.execute()
+        t.dep_changed = []
+        t.execute(Stream(0))
         got = "".join([a.out for a in t.actions])
         assert "hi_stdout_PY_hi_list" == got, repr(got)
 
@@ -318,16 +351,16 @@ class TestTaskTeardown(object):
         def put(x):
             got.append(x)
         t = task.Task('t1', [], teardown=[(put, [1]), (put, [2])])
-        t.execute()
-        assert None == t.execute_teardown()
+        t.execute(Stream(0))
+        assert None == t.execute_teardown(Stream(0))
         assert [1,2] == got
 
     def test_fail(self):
         def my_raise():
             raise Exception('hoho')
         t = task.Task('t1', [], teardown=[(my_raise,)])
-        t.execute()
-        got = t.execute_teardown()
+        t.execute(Stream(0))
+        got = t.execute_teardown(Stream(0))
         assert isinstance(got, CatchedException)
 
 
@@ -451,16 +484,49 @@ class TestTaskClean(object):
         t.clean(StringIO(), True)
         assert os.path.exists(tmpdir['dir'])
 
-    def test_dryrun_actions(self, tmpdir):
-        # a clean action can be anything, it can even not clean anything!
+    def test_dryrun_actions_not_executed(self, tmpdir):
+        # clean action is not executed at all if it does not contain
+        # a `dryrun` parameter
         self.executed = False
         def say_hello(): self.executed = True
-        t = task.Task("xxx",None,targets=tmpdir['files'], clean=[(say_hello,)])
+        t = task.Task("xxx", None, targets=tmpdir['files'],
+                      clean=[(say_hello,)])
         assert False == t._remove_targets
         assert 1 == len(t.clean_actions)
         t.clean(StringIO(), True)
         assert not self.executed
 
+    def test_dryrun_actions_with_param_true(self, tmpdir):
+        # clean action is not executed at all if it does not contain
+        # a `dryrun` parameter
+        self.executed = False
+        self.dryrun_val = None
+        def say_hello(dryrun):
+            self.executed = True
+            self.dryrun_val = dryrun
+        t = task.Task("xxx", None, targets=tmpdir['files'],
+                      clean=[(say_hello,)])
+        assert False == t._remove_targets
+        assert 1 == len(t.clean_actions)
+        t.clean(StringIO(), dryrun=True)
+        assert self.executed is True
+        assert self.dryrun_val is True
+
+    def test_dryrun_actions_with_param_false(self, tmpdir):
+        # clean action is not executed at all if it does not contain
+        # a `dryrun` parameter
+        self.executed = False
+        self.dryrun_val = None
+        def say_hello(dryrun):
+            self.executed = True
+            self.dryrun_val = dryrun
+        t = task.Task("xxx", None, targets=tmpdir['files'],
+                      clean=[(say_hello,)])
+        assert False == t._remove_targets
+        assert 1 == len(t.clean_actions)
+        t.clean(StringIO(), dryrun=False)
+        assert self.executed is True
+        assert self.dryrun_val is False
 
 
 class TestTaskDoc(object):
@@ -526,9 +592,7 @@ class TestDictToTask(object):
 
 
 class TestResultDep(object):
-    def test_single(self, depfile):
-        dep_manager = depfile
-
+    def test_single(self, dep_manager):
         tasks = {'t1': task.Task("t1", None, uptodate=[task.result_dep('t2')]),
                  't2': task.Task("t2", None),
                  }
@@ -557,9 +621,7 @@ class TestResultDep(object):
         assert 'up-to-date' == dep_manager.get_status(tasks['t1'], tasks).status
 
 
-    def test_group(self, depfile):
-        dep_manager = depfile
-
+    def test_group(self, dep_manager):
         tasks = {'t1': task.Task("t1", None, uptodate=[task.result_dep('t2')]),
                  't2': task.Task("t2", None, task_dep=['t2:a', 't2:b'],
                                  has_subtask=True),
